@@ -50,13 +50,13 @@
     </message>
     <message>
         <location filename="../HistoryPage.qml" line="54"/>
-        <source>Delete items</source>
-        <translation>Удалить пункты</translation>
+        <source>Do not delete items</source>
+        <translation>Не удалять пункты</translation>
     </message>
     <message>
         <location filename="../HistoryPage.qml" line="54"/>
-        <source>Do not delete items</source>
-        <translation>Не удалять пункты</translation>
+        <source>Delete items</source>
+        <translation>Удалить пункты</translation>
     </message>
     <message>
         <location filename="../HistoryPage.qml" line="57"/>
@@ -144,7 +144,7 @@
     </message>
     <message>
         <location filename="../InfoPage.qml" line="162"/>
-        <location filename="../InfoPage.qml" line="268"/>
+        <location filename="../InfoPage.qml" line="271"/>
         <source>Reset</source>
         <translation>Сбросить</translation>
     </message>
@@ -174,21 +174,17 @@
         <translation>поддержка</translation>
     </message>
     <message>
-        <source>Donate</source>
-        <translation type="obsolete">Пожертвовать</translation>
-    </message>
-    <message>
-        <location filename="../InfoPage.qml" line="266"/>
+        <location filename="../InfoPage.qml" line="269"/>
         <source>Reset all usage statistics</source>
         <translation>Сбросить всю статистику использования</translation>
     </message>
     <message>
-        <location filename="../InfoPage.qml" line="267"/>
+        <location filename="../InfoPage.qml" line="270"/>
         <source>Do you really want to reset all usage statistics?</source>
         <translation>Вы уверены, что хотите сбросить статистику?</translation>
     </message>
     <message>
-        <location filename="../InfoPage.qml" line="269"/>
+        <location filename="../InfoPage.qml" line="272"/>
         <source>Cancel</source>
         <translation>Отмена</translation>
     </message>
@@ -269,90 +265,95 @@
 <context>
     <name>OptionsPage</name>
     <message>
-        <location filename="../OptionsPage.qml" line="25"/>
+        <location filename="../OptionsPage.qml" line="27"/>
         <source>Page view</source>
         <translation>Просмотр</translation>
     </message>
     <message>
-        <location filename="../OptionsPage.qml" line="28"/>
+        <location filename="../OptionsPage.qml" line="30"/>
         <source>Rotation</source>
         <translation>Положение экрана</translation>
     </message>
     <message>
-        <location filename="../OptionsPage.qml" line="43"/>
+        <location filename="../OptionsPage.qml" line="45"/>
         <source>auto</source>
         <translation>авто</translation>
     </message>
     <message>
-        <location filename="../OptionsPage.qml" line="51"/>
+        <location filename="../OptionsPage.qml" line="53"/>
         <source>portrait</source>
         <translation>портретное</translation>
     </message>
     <message>
-        <location filename="../OptionsPage.qml" line="59"/>
+        <location filename="../OptionsPage.qml" line="61"/>
         <source>landscape</source>
         <translation>горизонтальное</translation>
     </message>
     <message>
-        <location filename="../OptionsPage.qml" line="67"/>
+        <location filename="../OptionsPage.qml" line="69"/>
         <source>Show status bar</source>
         <translation>Показывать панель статуса</translation>
     </message>
     <message>
-        <location filename="../OptionsPage.qml" line="75"/>
+        <location filename="../OptionsPage.qml" line="77"/>
         <source>Remember toolbar state</source>
         <translation>Запомнить настройки панели</translation>
     </message>
     <message>
-        <location filename="../OptionsPage.qml" line="82"/>
+        <location filename="../OptionsPage.qml" line="84"/>
         <source>Fullscreen button opacity</source>
         <translation>Кнопка полноэкранного обзора</translation>
     </message>
     <message>
-        <location filename="../OptionsPage.qml" line="108"/>
+        <location filename="../OptionsPage.qml" line="110"/>
         <source>Paging options</source>
         <translation>Настройки индексации</translation>
     </message>
     <message>
-        <location filename="../OptionsPage.qml" line="111"/>
+        <location filename="../OptionsPage.qml" line="113"/>
         <source>Paging mode</source>
         <translation>Индексация</translation>
     </message>
     <message>
-        <location filename="../OptionsPage.qml" line="126"/>
+        <location filename="../OptionsPage.qml" line="128"/>
         <source>Whole screen</source>
         <translation>во весь экран</translation>
     </message>
     <message>
-        <location filename="../OptionsPage.qml" line="134"/>
+        <location filename="../OptionsPage.qml" line="136"/>
         <source>On edges</source>
         <translation>До краев экрана</translation>
     </message>
     <message>
-        <location filename="../OptionsPage.qml" line="142"/>
+        <location filename="../OptionsPage.qml" line="144"/>
         <source>Show paging feedback</source>
         <translation>Показать отзыв индексации</translation>
     </message>
     <message>
-        <location filename="../OptionsPage.qml" line="152"/>
+        <location filename="../OptionsPage.qml" line="154"/>
         <source>Page scaling</source>
         <translation>Размер страницы</translation>
     </message>
     <message>
-        <location filename="../OptionsPage.qml" line="155"/>
+        <location filename="../OptionsPage.qml" line="157"/>
         <source>Page fit mode</source>
         <translation>Размер страницы</translation>
     </message>
     <message>
-        <location filename="../OptionsPage.qml" line="164"/>
+        <location filename="../OptionsPage.qml" line="166"/>
         <source>Miscellaneous</source>
         <translation>Смешаный</translation>
     </message>
     <message>
-        <location filename="../OptionsPage.qml" line="167"/>
+        <location filename="../OptionsPage.qml" line="169"/>
         <source>Manga reading mode</source>
         <translation>Manga чтение</translation>
     </message>
+    <message>
+        <location filename="../OptionsPage.qml" line="177"/>
+        <source>Show release notes</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PageFitSelector</name>
@@ -405,30 +406,53 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>WhatsNewDialog</name>
+    <message>
+        <location filename="../WhatsNewDialog.qml" line="35"/>
+        <source>Opening link</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../WhatsNewDialog.qml" line="48"/>
+        <source>&lt;b&gt;Do you like Mieru ? Donate !&lt;/b&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../WhatsNewDialog.qml" line="56"/>
+        <source>How to donate ?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../WhatsNewDialog.qml" line="67"/>
+        <source>Don&apos;t show again</source>
+        <translation type="unfinished">Не показывать больше</translation>
+    </message>
+</context>
 <context>
     <name>main</name>
     <message>
-        <location filename="../main.qml" line="83"/>
+        <location filename="../main.qml" line="85"/>
         <source>How to turn pages</source>
         <translation>Как листать страницы</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="84"/>
+        <location filename="../main.qml" line="86"/>
         <source>Tap the &lt;b&gt;right half&lt;/b&gt; of the screen to go to the &lt;b&gt;next page&lt;/b&gt;.</source>
         <translation>Нажмите на &lt;b&gt;правую часть экрана&lt;/b&gt; для перехода на след. страницу.</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="85"/>
+        <location filename="../main.qml" line="87"/>
         <source>Tap the &lt;b&gt;left half&lt;/b&gt; to go to the &lt;b&gt;previous page&lt;/b&gt;.</source>
         <translation>Нажмите на &lt;b&gt;левую часть&lt;/b&gt; для пред. страницы.</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="86"/>
+        <location filename="../main.qml" line="88"/>
         <source>Don&apos;t show again</source>
         <translation>Не показывать больше</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="87"/>
+        <location filename="../main.qml" line="89"/>
         <source>OK</source>
         <translation>Ага</translation>
     </message>
